/**
 * Copyright (c) 2021 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author David Sehnal <david.sehnal@gmail.com>
 */
import { arraySetAdd } from '../../mol-util/array';
export { UndirectedGraph };
var UndirectedGraph = /** @class */ (function () {
    function UndirectedGraph() {
        this.vertices = new Map();
        this.edges = new Map();
    }
    UndirectedGraph.prototype.addVertex = function (a, s) {
        this.vertices.set(a, s);
        if (!this.edges.has(a)) {
            this.edges.set(a, []);
        }
    };
    UndirectedGraph.prototype.addEdge = function (a, b) {
        arraySetAdd(this.edges.get(a), b);
        arraySetAdd(this.edges.get(b), a);
    };
    /**
     * Returns a connected component induced by a and
     * its unique representative.
     */
    UndirectedGraph.prototype.getComponent = function (a) {
        var pivot = a;
        var component = [];
        var visited = new Set();
        var stack = [a];
        while (stack.length > 0) {
            var e = stack.pop();
            component.push(e);
            visited.add(e);
            if (e < pivot)
                pivot = e;
            for (var _i = 0, _a = this.edges.get(e); _i < _a.length; _i++) {
                var b = _a[_i];
                if (visited.has(b))
                    continue;
                stack.push(b);
            }
        }
        return { pivot: pivot, component: component };
    };
    return UndirectedGraph;
}());
//# sourceMappingURL=undirected-graph.js.map